from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	def set(self, waypoints: str, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:LOCation:WAYPoints:FILE \n
		Snippet: driver.source.bb.gnss.receiver.v.location.waypoints.file.set(waypoints = '1', vehicle = repcap.Vehicle.Default) \n
		Selects a predefined or user-defined waypoint files to simulate a moving scenario. \n
			:param waypoints: Filename or complete file path incl. extension Waypoint files have the extension *.txt, *.nmea, *.kml or *.xtd.
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
		"""
		param = Conversions.value_to_quoted_str(waypoints)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:LOCation:WAYPoints:FILE {param}')

	def get(self, vehicle=repcap.Vehicle.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:LOCation:WAYPoints:FILE \n
		Snippet: value: str = driver.source.bb.gnss.receiver.v.location.waypoints.file.get(vehicle = repcap.Vehicle.Default) \n
		Selects a predefined or user-defined waypoint files to simulate a moving scenario. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: waypoints: Filename or complete file path incl. extension Waypoint files have the extension *.txt, *.nmea, *.kml or *.xtd."""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:LOCation:WAYPoints:FILE?')
		return trim_str_response(response)
