from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pucch:
	"""Pucch commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pucch", core, parent)

	@property
	def bd22(self):
		"""bd22 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bd22'):
			from .Bd22 import Bd22
			self._bd22 = Bd22(self._core, self._cmd_group)
		return self._bd22

	@property
	def tpas(self):
		"""tpas commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpas'):
			from .Tpas import Tpas
			self._tpas = Tpas(self._core, self._cmd_group)
		return self._tpas

	def clone(self) -> 'Pucch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pucch(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
