from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enhanced:
	"""Enhanced commands group definition. 47 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enhanced", core, parent)

	@property
	def channel(self):
		"""channel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import Channel
			self._channel = Channel(self._core, self._cmd_group)
		return self._channel

	@property
	def pccpch(self):
		"""pccpch commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_pccpch'):
			from .Pccpch import Pccpch
			self._pccpch = Pccpch(self._core, self._cmd_group)
		return self._pccpch

	@property
	def pcpich(self):
		"""pcpich commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pcpich'):
			from .Pcpich import Pcpich
			self._pcpich = Pcpich(self._core, self._cmd_group)
		return self._pcpich

	def clone(self) -> 'Enhanced':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Enhanced(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
